import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class EIndex(Enum):
  RUNNING=0
  INSTALLED=1
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in EIndex.__members__.values():
      if (act.value == checkValue):
        return act

    return EIndex.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'EIndex':
    try:
      return EIndex[name]
    except KeyError:
      return EIndex.SER_UNKNOWN 







import pyhausbus.HausBusUtils as HausBusUtils

class EvOn:
  CLASS_ID = 17
  FUNCTION_ID = 201

  def __init__(self,brightness:int, duration:int):
    self.brightness=brightness
    self.duration=duration


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvOn(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"EvOn(brightness={self.brightness}, duration={self.duration})"

  '''
  @param brightness aktuelle Helligkeit 0-100%.
  '''
  def getBrightness(self):
    return self.brightness

  '''
  @param duration Einschaltdauer: Wert in Sekunden\r\n0=Endlos.
  '''
  def getDuration(self):
    return self.duration






from pyhausbus.de.hausbus.homeassistant.proxy.drucksensor.params.ELastEvent import ELastEvent
import pyhausbus.HausBusUtils as HausBusUtils

class EvStatus:
  CLASS_ID = 48
  FUNCTION_ID = 203

  def __init__(self,value:int, lastEvent:ELastEvent):
    self.value=value
    self.lastEvent=lastEvent


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvStatus(HausBusUtils.bytesToWord(dataIn, offset), ELastEvent._fromBytes(dataIn, offset))

  def __str__(self):
    return f"EvStatus(value={self.value}, lastEvent={self.lastEvent})"

  '''
  @param value gemessener Druck in Pa.
  '''
  def getValue(self):
    return self.value

  '''
  @param lastEvent .
  '''
  def getLastEvent(self):
    return self.lastEvent






from pyhausbus.de.hausbus.homeassistant.proxy.dimmer.params.EDirection import EDirection
import pyhausbus.HausBusUtils as HausBusUtils

class EvStart:
  CLASS_ID = 17
  FUNCTION_ID = 202

  def __init__(self,direction:EDirection):
    self.direction=direction


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvStart(EDirection._fromBytes(dataIn, offset))

  def __str__(self):
    return f"EvStart(direction={self.direction})"

  '''
  @param direction .
  '''
  def getDirection(self):
    return self.direction



